@@ -22,7 +22,7 @@ our @EXPORT = qw(
   num2word
 );
 
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 =head1 NAME
 
@@ -151,11 +151,9 @@ sub num2word {
 1;
 __END__
 
-=head1 MESSAGE FROM THE AUTHOR
+=head1 SEE ALSO
 
-If you're using this module, please drop me a line to my e-mail. Tell me what
-you're doing with it. Also, feel free to suggest new bugs^H^H^H^H^H features
-O:-)
+http://natura.di.uminho.pt (Project for Portuguese Natural Language Processing)
 
 =head1 AUTHOR
 
